@@ -1,5 +1,5 @@
 import argparse
-import importlib
+from importlib import util, machinery
 import os
 import shutil
 import sys
@@ -92,10 +92,10 @@ def main():
     # below, which needs to operate in the context of our new module.
     # NOTE: We use SourceFileLoader, rather than allowing importlib to infer
     # the proper loader, in order to support files without a .py extension.
-    spec = importlib.util.spec_from_loader(
-        "__main__", importlib.machinery.SourceFileLoader("__main__", target_file)
+    spec = util.spec_from_loader(
+        "__main__", machinery.SourceFileLoader("__main__", target_file)
     )
-    mod = importlib.util.module_from_spec(spec)
+    mod = util.module_from_spec(spec)
     sys.modules.update({"__main__": mod})
 
     # Ensure we're setup to be able to run.
